@@ -11,7 +11,11 @@ tmuxp
 from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
 
-__version__ = '0.1.1'
+__title__ = 'tmuxp'
+__version__ = '0.1.2'
+__author__ = 'Tony Narlock'
+__license__ = 'BSD'
+__copyright__ = 'Copyright 2013 Tony Narlock'
 
 from .session import Session
 from .server import Server
