@@ -4,9 +4,6 @@
 tmuxp.cli
 ~~~~~~~~~
 
-:copyright: Copyright 2013 Tony Narlock.
-:license: BSD, see LICENSE for details
-
 """
 from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
@@ -257,7 +254,6 @@ def load_workspace(config_file, args):
     :param type: string
 
     """
-    logger.info('Loading %s.' % config_file)
 
     sconfig = kaptan.Kaptan()
     sconfig = sconfig.import_config(config_file).get()
@@ -279,12 +275,13 @@ def load_workspace(config_file, args):
     tmux_bin = util.which('tmux')
 
     try:
+        logger.info('Loading %s.' % config_file)
         builder.build()
 
         if 'TMUX' in os.environ:
-            if args.answer_yes or prompt_yes_no(
+            if not args.detached and (args.answer_yes or prompt_yes_no(
                 'Already inside TMUX, switch to session?'
-            ):
+            )):
                 tmux_env = os.environ.pop('TMUX')
                 builder.session.switch_client()
 
@@ -293,9 +290,12 @@ def load_workspace(config_file, args):
             else:
                 sys.exit('Session created in detached state.')
 
-        builder.session.attach_session()
+        if not args.detached:
+            builder.session.attach_session()
     except exc.TmuxSessionExists as e:
-        if args.answer_yes or prompt_yes_no('%s Attach?' % e):
+        if not args.detached and (
+            args.answer_yes or prompt_yes_no('%s Attach?' % e)
+        ):
             if 'TMUX' in os.environ:
                 builder.session.switch_client()
 
@@ -848,6 +848,14 @@ def get_parser():
     )
     load.set_defaults(callback=command_load)
 
+    load.add_argument(
+        '-d',
+        dest='detached',
+        default=None,
+        help='Load a session without attaching to it.',
+        action='store_true'
+    )
+
     convert = subparsers.add_parser(
         'convert',
         help='Convert tmuxp config between YAML and JSON format.'
