@@ -4,16 +4,15 @@
 tmuxp.pane
 ~~~~~~~~~~
 
-tmuxp helps you manage tmux workspaces.
-
-:copyright: Copyright 2013 Tony Narlock.
-:license: BSD, see LICENSE for details
-
 """
-from __future__ import absolute_import, division, print_function, with_statement
-from . import util, formats, exc
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
+
 import logging
 
+from . import util, formats, exc
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -157,6 +156,18 @@ class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
         """
         self.tmux('send-keys', 'Enter')
 
+    def select_pane(self):
+        """Select pane. Return ``self``.
+
+        To select a window object asynchrously. If a ``pane`` object exists
+        and is no longer longer the current window, ``w.select_pane()``
+        will make ``p`` the current pane.
+
+        :rtype: :class:`pane`
+
+        """
+        return self.window.select_pane(self.get('pane_id'))
+
     def __repr__(self):
         return "%s(%s %s)" % (
             self.__class__.__name__,
