@@ -4,19 +4,16 @@
 tmuxp.server
 ~~~~~~~~~~~~
 
-tmuxp helps you manage tmux workspaces.
-
-:copyright: Copyright 2013 Tony Narlock.
-:license: BSD, see LICENSE for details
-
 """
-from __future__ import absolute_import, division, print_function, with_statement
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
+import logging
+
 from .util import tmux, TmuxRelationalObject
 from .session import Session
 from . import formats, exc
-import logging
 
 logger = logging.getLogger(__name__)
 
